==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/WebRatingSymbolDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebRatingSymbolDescription } from "./WebRatingSymbolDescription";
/**
 * @hidden
 */
var WebRatingSymbolDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebRatingSymbolDescriptionMetadata, _super);
    function WebRatingSymbolDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebRatingSymbolDescriptionMetadata.b = function (a) {
        if (WebRatingSymbolDescriptionMetadata.a == null) {
            WebRatingSymbolDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebRatingSymbolDescriptionMetadata.c(WebRatingSymbolDescriptionMetadata.a);
        }
        if (a.g(WebRatingSymbolDescriptionMetadata.a)) {
            return;
        }
        a.s(WebRatingSymbolDescriptionMetadata.a);
    };
    WebRatingSymbolDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:RatingSymbol");
    };
    WebRatingSymbolDescriptionMetadata.d = function (a) {
        WebRatingSymbolDescriptionMetadata.b(a);
        a.u("WebRatingSymbol", function () { return new WebRatingSymbolDescription(); });
        a.t("WebRatingSymbol", WebRatingSymbolDescriptionMetadata.a);
    };
    WebRatingSymbolDescriptionMetadata.$t = markType(WebRatingSymbolDescriptionMetadata, 'WebRatingSymbolDescriptionMetadata');
    WebRatingSymbolDescriptionMetadata.a = null;
    return WebRatingSymbolDescriptionMetadata;
}(Base));
export { WebRatingSymbolDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebRatingSymbolDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebRatingSymbolDescription } from "./WebRatingSymbolDescription";
/**
 * @hidden
 */
var WebRatingSymbolDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebRatingSymbolDescriptionMetadata, _super);
    function WebRatingSymbolDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebRatingSymbolDescriptionMetadata.b = function (a) {
        if (WebRatingSymbolDescriptionMetadata.a == null) {
            WebRatingSymbolDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebRatingSymbolDescriptionMetadata.c(WebRatingSymbolDescriptionMetadata.a);
        }
        if (a.j(WebRatingSymbolDescriptionMetadata.a)) {
            return;
        }
        a.y(WebRatingSymbolDescriptionMetadata.a);
    };
    WebRatingSymbolDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:RatingSymbol");
        a.item("__tagNameWC", "String:igc-rating-symbol");
    };
    WebRatingSymbolDescriptionMetadata.d = function (a) {
        WebRatingSymbolDescriptionMetadata.b(a);
        a.aa("WebRatingSymbol", function () { return new WebRatingSymbolDescription(); });
        a.z("WebRatingSymbol", WebRatingSymbolDescriptionMetadata.a);
    };
    WebRatingSymbolDescriptionMetadata.$t = markType(WebRatingSymbolDescriptionMetadata, 'WebRatingSymbolDescriptionMetadata');
    WebRatingSymbolDescriptionMetadata.a = null;
    return WebRatingSymbolDescriptionMetadata;
}(Base));
export { WebRatingSymbolDescriptionMetadata };
